<template>
  <div class="module-box">
    <div class="chang-btn"
      @click="
        isUp = !isUp;
        setOption();
      "
    >
      {{ isUp ? '升序▲' : '降序▼' }}
    </div>
    <div class="city-score" ref="cityScore"></div>
  </div>
</template>

<script>
import echarts from 'echarts';

let cityChart = null;
export default {
  name: 'city-score',
  data() {
    return {
      isUp: true, // 当前是否为升序
      // 缓存下来的异步获取的数据列表
      dataList: [
        {
          name: '郑州',
          score: 153,
        },
        {
          name: '洛阳',
          score: 153,
        },
        {
          name: '南阳',
          score: 243,
        },
        {
          name: '信阳',
          score: 53,
        },
      ],
    };
  },
  methods: {
    // 绘制图表
    setOption() {
      if (!cityChart) {
        return;
      }
      const sortArr = this.dataList.sort((a, b) => (this.isUp ? a.score - b.score : b.score - a.score)); // 排序后的数据列表
      const nameArr = sortArr.map((i) => i.name);
      const dataArr = sortArr.map((i) => i.score);
      let maxScore = Math.floor(Math.max(...dataArr) * 1.4); // 为了视觉阴影效果  留点余地
      maxScore = sortArr.map(() => maxScore);
      cityChart.setOption({
        tooltip: {
          trigger: 'axis',
        },
        grid: {
          right: 20,
          left: 50,
          top: 30,
          bottom: 20,
        },
        xAxis: [
          {
            type: 'category',
            axisLine: {
              lineStyle: {
                color: '#0D496E',
              },
            },
            axisLabel: {
              show: true,
              textStyle: {
                fontSize: 12,
                color: '#ADB1B4',
              },
            },
            data: nameArr,
          },
          // 生成背景阴影需要
          {
            type: 'category',
            show: false,
            data: nameArr,
          },
        ],
        yAxis: {
          type: 'value',
          splitLine: {
            show: false,
          },
          axisLine: {
            show: false,
          },
          axisLabel: {
            show: true,
            textStyle: {
              fontSize: 12,
              color: '#ADB1B4',
            },
          },
        },
        series: [
          {
            name: '评分',
            data: dataArr,
            type: 'pictorialBar',
            barWidth: 48,
            symbol: 'triangle',
            label: {
              show: true,
              position: 'top',
              textStyle: {
                fontSize: 16,
                color: '#fff',
              },
            },
            itemStyle: {
              color: {
                type: 'linear',
                x: 0,
                y: 0,
                x2: 0,
                y2: 1,
                colorStops: [
                  {
                    offset: 0,
                    color: 'rgba(30, 231, 231, 0.87)', // 0% 处的颜色
                  },
                  {
                    offset: 1,
                    color: 'rgba(30, 231, 231, 0)', // 100% 处的颜色
                  },
                ],
                global: false, // 缺省为 false
              },
            },
          },
          // 制造背景阴影
          {
            tooltip: {
              show: false,
            },
            xAxisIndex: 1,
            itemStyle: {
              color: 'rgba(180, 180, 180, 0.2)',
            },
            data: maxScore,
            barWidth: 48,
            emphasis: {
              itemStyle: {
                color: {
                  type: 'linear',
                  x: 0,
                  x2: 0,
                  y: 0,
                  y2: 1,
                  colorStops: [
                    {
                      offset: 0,
                      color: 'rgba(64, 247, 176, 0.25)',
                    },
                    {
                      offset: 1,
                      color: 'rgba(17, 34, 64, 0.25)',
                    },
                  ],
                },
              },
            },
            type: 'bar',
          },
        ],
      });
    },
  },
  mounted() {
    // 监听屏幕宽度变化：当浏览器发生resize事件的时候，触发echart的resize事件，重绘canvas
    // 基于准备好的dom，初始化echarts实例
    cityChart = echarts.init(this.$refs.cityScore);
    window.addEventListener('resize', () => {
      this.$nextTick(() => {
        cityChart.resize();
      });
    });
    this.setOption();
  },
};
</script>

<style lang="scss" scoped>
.module-box {
  width: 100%;
  height: 100%;
  position: relative;
}
.city-score {
  width: 100%;
  height: 100%;
}

.chang-btn {
  position: absolute;
  white-space: nowrap;
  right: -5px;
  top: -5px;
  font-size: 14px;
  color: #ADB1B4;
  cursor: pointer;
  z-index: 9;
}
</style>
